@@ -1,5 +1,5 @@
 // Copyright Contributors to the OpenVDB Project
-// SPDX-License-Identifier: MPL-2.0
+// SPDX-License-Identifier: Apache-2.0
 
 #include <openvdb_ax/compiler/Compiler.h>
 #include <openvdb_ax/compiler/PointExecutable.h>
@@ -20,6 +20,12 @@ class TestPointExecutable : public CppUnit::TestCase
 {
 public:
 
+#if OPENVDB_ABI_VERSION_NUMBER >= 12
+    using LeafIndexType = openvdb::Index64;
+#else
+    using LeafIndexType = openvdb::Index32;
+#endif
+
     CPPUNIT_TEST_SUITE(TestPointExecutable);
     CPPUNIT_TEST(testConstructionDestruction);
     CPPUNIT_TEST(testCreateMissingAttributes);
@@ -545,7 +551,7 @@ TestPointExecutable::testAttributeCodecs()
             points = points::createPointDataGrid
                 <points::NullCodec, points::PointDataGrid>
                     (twoPoints, *defaultTransform);
-        CPPUNIT_ASSERT_EQUAL(points->tree().leafCount(), Index32(1));
+        CPPUNIT_ASSERT_EQUAL(points->tree().leafCount(), LeafIndexType(1));
 
         // collapsed uniform 0 attributes
         points::appendAttribute<float, points::NullCodec>(points->tree(), "f");
@@ -641,7 +647,7 @@ TestPointExecutable::testAttributeCodecs()
             points = points::createPointDataGrid
                 <points::NullCodec, points::PointDataGrid>
                     (twoPoints, *defaultTransform);
-        CPPUNIT_ASSERT_EQUAL(points->tree().leafCount(), Index32(1));
+        CPPUNIT_ASSERT_EQUAL(points->tree().leafCount(), LeafIndexType(1));
 
         // collapsed uniform 0 attributes
         points::appendAttribute<Vec3f, points::FixedPointCodec<true, points::UnitRange>>(points->tree(), "fpu8");
@@ -728,7 +734,7 @@ TestPointExecutable::testAttributeCodecs()
             points = points::createPointDataGrid
                 <points::FixedPointCodec<true, points::PositionRange>, points::PointDataGrid>
                     (twoPoints, *defaultTransform);
-        CPPUNIT_ASSERT_EQUAL(points->tree().leafCount(), Index32(1));
+        CPPUNIT_ASSERT_EQUAL(points->tree().leafCount(), LeafIndexType(1));
 
         points::appendAttribute<float, points::TruncateCodec>(points->tree(), "t");
         points::appendAttribute<Vec3f, points::FixedPointCodec<false, points::PositionRange>>(points->tree(), "f");
